# Windows/Mac Installers

Pre-packaged installers are available for Windows/Mac. These provide a quick and simple way to get started, as they do 
require a base Python installation to be pre-installed. 

- [Latest Windows Installer](https://github.com/lbl-camera/tsuchinoko/releases/latest/download/Tsuchinoko-amd64.exe)
- [Latest Mac OSX Installer](https://github.com/lbl-camera/tsuchinoko/releases/latest/download/Tsuchinoko.app.tgz)

## Limitations

Although these installers provide all necessary components to run the included demos and many custom adaptive 
experiments, these installers are limited in what Python packages are included. If your experiment requires a 
Python package that is not included, you may want to use a [standard installation](quickstart.md).
